@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,22 +38,20 @@
 #include "common.h"
 #include "SharedHandle.h"
 #include <deque>
+#include <vector>
 
 namespace aria2 {
 
-class Randomizer;
-
 class BitfieldMan {
 private:
   size_t blockLength;
   uint64_t totalLength;
-  unsigned char* bitfield;
-  unsigned char* useBitfield;
-  unsigned char* filterBitfield;
   size_t bitfieldLength;
   size_t blocks;
   bool filterEnabled;
-  SharedHandle<Randomizer> randomizer;
+  unsigned char* bitfield;
+  unsigned char* useBitfield;
+  unsigned char* filterBitfield;
 
   // for caching
   size_t cachedNumMissingBlock;
@@ -62,20 +60,6 @@ private:
   uint64_t cachedFilteredComletedLength;
   uint64_t cachedFilteredTotalLength;
 
-  size_t getNthBitIndex(const unsigned char bit, size_t nth) const;
-  bool getMissingIndexRandomly(size_t& index, const unsigned char* bitfield, size_t len) const;
-
-  template<typename Array>
-  bool getMissingIndexRandomly(size_t& index, const Array& bitfield,
-			       size_t bitfieldLength) const;
-  template<typename Array>
-  bool getFirstMissingIndex(size_t& index, const Array& bitfield, size_t bitfieldLength) const;
-
-  template<typename Array>
-  bool getAllMissingIndexes(std::deque<size_t>& indexes,
-			    const Array& bitfield,
-			    size_t bitfieldLength) const;
-
   bool setBitInternal(unsigned char* bitfield, size_t index, bool on);
   bool setFilterBit(size_t index);
 
@@ -84,13 +68,17 @@ private:
 
   uint64_t getCompletedLength(bool useFilter) const;
 
+  // If filterBitfield is 0, allocate bitfieldLength bytes to it and
+  // set 0 to all bytes.
+  void ensureFilterBitfield();
+public:
   // [startIndex, endIndex)
   class Range {
   public:
     size_t startIndex;
     size_t endIndex;
     Range(size_t startIndex = 0, size_t endIndex = 0):startIndex(startIndex),
-						      endIndex(endIndex) {}
+                                                      endIndex(endIndex) {}
   
     size_t getSize() const {
       return endIndex-startIndex;
@@ -125,64 +113,53 @@ public:
 
   uint64_t getTotalLength() const { return totalLength; }
 
-  /**
-   * affected by filter
-   */
+  // Returns true iff there is a bit index which is set in bitfield,
+  // but not set in this object.
+  //
+  // affected by filter
   bool hasMissingPiece(const unsigned char* bitfield, size_t len) const;
-  /**
-   * affected by filter
-   */
-  bool getMissingIndex(size_t& index, const unsigned char* bitfield, size_t len) const;
-  /**
-   * affected by filter
-   */
-  bool getMissingIndex(size_t& index) const;
-  /**
-   * affected by filter
-   */
-  bool getFirstMissingUnusedIndex(size_t& index, const unsigned char* bitfield, size_t len) const;
-  /**
-   * affected by filter
-   */
+
+  // affected by filter
   bool getFirstMissingUnusedIndex(size_t& index) const;
-  /**
-   * affected by filter
-   */
+
+  // Appends at most n missing unused index to out. This function
+  // doesn't delete existing elements in out.  Returns the number of
+  // appended elements.
+  //
+  // affected by filter
+  size_t getFirstNMissingUnusedIndex(std::vector<size_t>& out, size_t n) const;
+
+  // Stores first missing bit index to index. Returns true if such bit
+  // index is found. Otherwise returns false.
+  //
+  // affected by filter
   bool getFirstMissingIndex(size_t& index) const;
-  /**
-   * affected by filter
-   */
-  bool getMissingUnusedIndex(size_t& index, const unsigned char* bitfield, size_t len) const;
-  /**
-   * affected by filter
-   */
-  bool getMissingUnusedIndex(size_t& index) const;
-  /**
-   * affected by filter
-   */
-  bool getSparseMissingUnusedIndex(size_t& index) const;
-  /**
-   * affected by filter
-   */
+
+  // Stores missing bit index to index. index is selected so that it
+  // divides longest missing bit subarray into 2 equally sized
+  // subarray. Set bits in ignoreBitfield are excluded. Returns true
+  // if such bit index is found. Otherwise returns false.
+  //
+  // affected by filter
+  bool getSparseMissingUnusedIndex
+  (size_t& index,
+   const unsigned char* ignoreBitfield,
+   size_t ignoreBitfieldLength) const;
+
+  // affected by filter
   bool getAllMissingIndexes(unsigned char* misbitfield, size_t mislen) const;
-  /**
-   * affected by filter
-   */
+
+  // affected by filter
   bool getAllMissingIndexes(unsigned char* misbitfield, size_t mislen,
-			    const unsigned char* bitfield, size_t len) const;
-  /**
-   * affected by filter
-   */
+                            const unsigned char* bitfield, size_t len) const;
+  // affected by filter
   bool getAllMissingUnusedIndexes(unsigned char* misbitfield, size_t mislen,
-				  const unsigned char* bitfield,
-				  size_t len) const;
-  /**
-   * affected by filter
-   */
+                                  const unsigned char* bitfield,
+                                  size_t len) const;
+  // affected by filter
   size_t countMissingBlock() const;
-  /**
-   * affected by filter
-   */
+
+  // affected by filter
   size_t countMissingBlockNow() const;
 
   bool setUseBit(size_t index);
@@ -194,13 +171,13 @@ public:
   bool isBitSet(size_t index) const;
   bool isUseBitSet(size_t index) const;
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   bool isFilteredAllBitSet() const;
 
   bool isAllBitSet() const;
 
+  bool isAllFilterBitSet() const;
+
   const unsigned char* getBitfield() const
   {
     return bitfield;
@@ -211,9 +188,7 @@ public:
     return bitfieldLength;
   }
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   size_t countFilteredBlock() const
   {
     return cachedNumFilteredBlock;
@@ -224,9 +199,7 @@ public:
     return blocks;
   }
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   size_t countFilteredBlockNow() const;
 
   size_t getMaxIndex() const
@@ -243,9 +216,11 @@ public:
   void setAllUseBit();
 
   void addFilter(uint64_t offset, uint64_t length);
-  /**
-   * Clears filter and disables filter
-   */
+  void removeFilter(uint64_t offset, uint64_t length);
+  // Add filter not in the range of [offset, offset+length) bytes
+  void addNotFilter(uint64_t offset, uint64_t length);
+
+  // Clears filter and disables filter
   void clearFilter();
   
   void enableFilter();
@@ -255,17 +230,13 @@ public:
     return filterEnabled;
   }
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   uint64_t getFilteredTotalLength() const
   {
     return cachedFilteredTotalLength;
   }
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   uint64_t getFilteredTotalLengthNow() const;
 
   uint64_t getCompletedLength() const
@@ -275,25 +246,15 @@ public:
 
   uint64_t getCompletedLengthNow() const;
 
-  /**
-   * affected by filter
-   */
+  // affected by filter
   uint64_t getFilteredCompletedLength() const
   {
     return cachedFilteredComletedLength;
   }
-  /**
-   * affected by filter
-   */
+
+  // affected by filter
   uint64_t getFilteredCompletedLengthNow() const;
 
-  void setRandomizer(const SharedHandle<Randomizer>& randomizer);
-
-  const SharedHandle<Randomizer>& getRandomizer() const
-  {
-    return randomizer;
-  }
-
   void updateCache();
 
   bool isBitRangeSet(size_t startIndex, size_t endIndex) const;
@@ -306,6 +267,10 @@ public:
 
   uint64_t getMissingUnusedLength(size_t startingIndex) const;
 
+  const unsigned char* getFilterBitfield() const
+  {
+    return filterBitfield;
+  }
 };
 
 } // namespace aria2
