@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -49,8 +49,13 @@ typedef std::map<std::string, uint8_t> Extensions;
 
 #define INFO_HASH_LENGTH 20
 
-#define DEFAULT_LATENCY 1500
-
 #define MAX_BLOCK_LENGTH (16*1024)
 
+#define DEFAULT_MAX_OUTSTANDING_REQUEST 6
+
+// Upper Bound of the number of outstanding request
+#define UB_MAX_OUTSTANDING_REQUEST 24
+
+#define METADATA_PIECE_SIZE (16*1024)
+
 #endif // _D_BT_CONSTANTS_
