@@ -39,6 +39,7 @@
 
 #include <string>
 #include <deque>
+#include <algorithm>
 
 #include "a2time.h"
 #include "Cookie.h"
@@ -49,8 +50,73 @@ namespace aria2 {
 class Logger;
 
 class CookieStorage {
+public:
+
+  static const size_t MAX_COOKIE_PER_DOMAIN = 50;
+
+  class DomainEntry {
+  private:
+    std::string _key;
+
+    time_t _lastAccess;
+
+    std::deque<Cookie> _cookies;
+  public:
+    DomainEntry(const std::string& domain);
+
+    const std::string& getKey() const
+    {
+      return _key;
+    }
+
+    template<typename OutputIterator>
+    OutputIterator findCookie
+    (OutputIterator out,
+     const std::string& requestHost,
+     const std::string& requestPath,
+     time_t date, bool secure)
+    {
+      for(std::deque<Cookie>::iterator i = _cookies.begin();
+          i != _cookies.end(); ++i) {
+        if((*i).match(requestHost, requestPath, date, secure)) {
+          (*i).updateLastAccess();
+          out++ = *i;
+        }
+      }
+      return out;
+    }
+
+    size_t countCookie() const
+    {
+      return _cookies.size();
+    }
+
+    bool addCookie(const Cookie& cookie);
+
+    void updateLastAccess();
+
+    time_t getLastAccess() const
+    {
+      return _lastAccess;
+    }
+
+    void writeCookie(std::ostream& o) const;
+
+    bool contains(const Cookie& cookie) const;
+
+    template<typename OutputIterator>
+    OutputIterator dumpCookie(OutputIterator out) const
+    {
+      return std::copy(_cookies.begin(), _cookies.end(), out);
+    }
+
+    bool operator<(const DomainEntry& de) const
+    {
+      return _key < de._key;
+    }
+  };
 private:
-  std::deque<Cookie> _cookies;
+  std::deque<DomainEntry> _domains;
 
   CookieParser _parser;
 
@@ -72,9 +138,11 @@ public:
                      const std::string& requestHost,
                      const std::string& requestPath);
 
+  // Finds cookies matched with given criteria and returns them.
+  // Matched cookies' _lastAccess property is updated.
   std::deque<Cookie> criteriaFind(const std::string& requestHost,
                                   const std::string& requestPath,
-                                  time_t date, bool secure) const;
+                                  time_t date, bool secure);
 
   // Loads Cookies from file denoted by filename.  If compiled with
   // libsqlite3, this method automatically detects the specified file
@@ -88,18 +156,22 @@ public:
   // this method returns true, otherwise returns false.
   bool saveNsFormat(const std::string& filename);
 
+  // Returns the number of cookies this object stores.
   size_t size() const;
   
-  std::deque<Cookie>::const_iterator begin() const
-  {
-    return _cookies.begin();
-  }
+  // Returns true if this object contains a cookie x where x == cookie
+  // satisfies.
+  bool contains(const Cookie& cookie) const;
 
-  std::deque<Cookie>::const_iterator end() const
+  template<typename OutputIterator>
+  OutputIterator dumpCookie(OutputIterator out) const
   {
-    return _cookies.end();
+    for(std::deque<DomainEntry>::const_iterator i = _domains.begin();
+        i != _domains.end(); ++i) {
+      out = (*i).dumpCookie(out);
+    }
+    return out;
   }
-
 };
 
 } // namespace aria2
