@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,16 +34,17 @@
 /* copyright --> */
 #include "DHTResponseMessage.h"
 #include "DHTNode.h"
-#include "Util.h"
+#include "util.h"
 #include "bencode.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
 const std::string DHTResponseMessage::R("r");
 
 DHTResponseMessage::DHTResponseMessage(const SharedHandle<DHTNode>& localNode,
-				       const SharedHandle<DHTNode>& remoteNode,
-				       const std::string& transactionID):
+                                       const SharedHandle<DHTNode>& remoteNode,
+                                       const std::string& transactionID):
   DHTAbstractMessage(localNode, remoteNode, transactionID) {}
 
 DHTResponseMessage::~DHTResponseMessage() {}
@@ -65,12 +66,12 @@ bool DHTResponseMessage::isReply() const
 
 std::string DHTResponseMessage::toString() const
 {
-  return "dht response "+getMessageType()+
-    " TransactionID="+Util::toHex(_transactionID)+
-    " Remote:"+
-    _remoteNode->getIPAddress()+":"+Util::uitos(_remoteNode->getPort())+
-    ", id="+Util::toHex(_remoteNode->getID(), DHT_ID_LENGTH)+
-    ", "+toStringOptional();
+  return strconcat("dht response ", getMessageType(),
+                   " TransactionID=", util::toHex(_transactionID),
+                   " Remote:", _remoteNode->getIPAddress(),
+                   ":", util::uitos(_remoteNode->getPort()),
+                   ", id=", util::toHex(_remoteNode->getID(), DHT_ID_LENGTH),
+                   ", ", toStringOptional());
 }
 
 } // namespace aria2
