@@ -292,6 +292,11 @@ void EpollEventPoll::AsyncNameResolverEntry::removeSocketEvents
   }
 }
 
+void EpollEventPoll::AsyncNameResolverEntry::processTimeout()
+{
+  _nameResolver->process(ARES_SOCKET_BAD, ARES_SOCKET_BAD);
+}
+
 #endif // ENABLE_ASYNC_DNS
 
 EpollEventPoll::EpollEventPoll():_logger(LogFactory::getInstance())
@@ -336,6 +341,19 @@ void EpollEventPoll::poll(const struct timeval& tv)
     }
   }
 
+#ifdef ENABLE_ASYNC_DNS
+  // It turns out that we have to call ares_process_fd before ares's
+  // own timeout and ares may create new sockets or closes socket in
+  // their API. So we call ares_process_fd for all ares_channel and
+  // re-register their sockets.
+  for(std::deque<SharedHandle<AsyncNameResolverEntry> >::iterator i =
+        _nameResolverEntries.begin(); i != _nameResolverEntries.end(); ++i) {
+    (*i)->processTimeout();
+    (*i)->removeSocketEvents(this);
+    (*i)->addSocketEvents(this);
+  }
+#endif // ENABLE_ASYNC_DNS
+
   // TODO timeout of name resolver is determined in Command(AbstractCommand,
   // DHTEntryPoint...Command)
 }
@@ -387,7 +405,10 @@ bool EpollEventPoll::addEvents(sock_t socket,
                   &socketEntry->getEpEvent());
   }
   if(r == -1) {
-    _logger->debug("Failed to add socket event %d:%s", socket, strerror(errno));
+    if(_logger->debug()) {
+      _logger->debug("Failed to add socket event %d:%s",
+                     socket, strerror(errno));
+    }
     return false;
   } else {
     return true;
@@ -432,18 +453,24 @@ bool EpollEventPoll::deleteEvents(sock_t socket,
       r = epoll_ctl(_epfd, EPOLL_CTL_MOD, (*i)->getSocket(),
                     &(*i)->getEpEvent());
       if(r == -1) {
-        _logger->debug("Failed to delete socket event, but may be ignored:%s",
-                       strerror(errno));
+        if(_logger->debug()) {
+          _logger->debug("Failed to delete socket event, but may be ignored:%s",
+                         strerror(errno));
+        }
       }
     }
     if(r == -1) {
-      _logger->debug("Failed to delete socket event:%s", strerror(errno));
+      if(_logger->debug()) {
+        _logger->debug("Failed to delete socket event:%s", strerror(errno));
+      }
       return false;
     } else {
       return true;
     }
   } else {
-    _logger->debug("Socket %d is not found in SocketEntries.", socket);
+    if(_logger->debug()) {
+      _logger->debug("Socket %d is not found in SocketEntries.", socket);
+    }
     return false;
   }
 }
