@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -112,6 +112,8 @@ private:
     virtual void removeSelf(const SharedHandle<SocketEntry>& socketEntry) const;
   };
   
+#ifdef ENABLE_ASYNC_DNS
+
   class ADNSEvent : public Event {
   private:
     SharedHandle<AsyncNameResolver> _resolver;
@@ -120,7 +122,7 @@ private:
     int _events;
   public:
     ADNSEvent(const SharedHandle<AsyncNameResolver>& resolver, Command* command,
-	      sock_t socket, int events);
+              sock_t socket, int events);
     
     bool operator==(const ADNSEvent& event) const
     {
@@ -136,6 +138,7 @@ private:
     virtual void removeSelf(const SharedHandle<SocketEntry>& socketEntry) const;
   };
 
+#endif // ENABLE_ASYNC_DNS
 
   class SocketEntry {
   private:
@@ -202,17 +205,21 @@ private:
 
   public:
     AsyncNameResolverEntry(const SharedHandle<AsyncNameResolver>& nameResolver,
-			   Command* command);
+                           Command* command);
 
     bool operator==(const AsyncNameResolverEntry& entry)
     {
       return _nameResolver == entry._nameResolver &&
-	_command == entry._command;
+        _command == entry._command;
     }
 
     void addSocketEvents(EpollEventPoll* socketPoll);
     
     void removeSocketEvents(EpollEventPoll* socketPoll);
+
+    // Calls AsyncNameResolver::process(ARES_SOCKET_BAD,
+    // ARES_SOCKET_BAD).
+    void processTimeout();
   };
 
 #endif // ENABLE_ASYNC_DNS
@@ -242,10 +249,10 @@ private:
   bool deleteEvents(sock_t socket, const Event& event);
 
   bool addEvents(sock_t socket, Command* command, int events,
-		 const SharedHandle<AsyncNameResolver>& rs);
+                 const SharedHandle<AsyncNameResolver>& rs);
 
   bool deleteEvents(sock_t socket, Command* command,
-		    const SharedHandle<AsyncNameResolver>& rs);
+                    const SharedHandle<AsyncNameResolver>& rs);
 
 public:
   EpollEventPoll();
@@ -257,14 +264,14 @@ public:
   virtual void poll(const struct timeval& tv);
 
   virtual bool addEvents(sock_t socket,
-			 Command* command, EventPoll::EventType events);
+                         Command* command, EventPoll::EventType events);
 
   virtual bool deleteEvents(sock_t socket,
-			    Command* command, EventPoll::EventType events);
+                            Command* command, EventPoll::EventType events);
 #ifdef ENABLE_ASYNC_DNS
 
   virtual bool addNameResolver(const SharedHandle<AsyncNameResolver>& resolver,
-			       Command* command);
+                               Command* command);
   virtual bool deleteNameResolver
   (const SharedHandle<AsyncNameResolver>& resolver, Command* command);
 #endif // ENABLE_ASYNC_DNS
