@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,7 +37,7 @@
 #include <numeric>
 
 #include "array_fun.h"
-#include "Util.h"
+#include "util.h"
 #include "Request.h"
 
 namespace aria2 {
@@ -158,7 +158,7 @@ std::string FeatureConfig::featureSummary() const
       s += ", ";
     }
   }
-  return Util::trim(s, ", ");
+  return util::trim(s, ", ");
 }
 
 } // namespace aria2
