@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -50,20 +50,23 @@
 #include "prefs.h"
 #include "HttpConnection.h"
 #include "Socket.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
 FtpInitiateConnectionCommand::FtpInitiateConnectionCommand
 (int cuid,
  const RequestHandle& req,
+ const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e)
-  :InitiateConnectionCommand(cuid, req, requestGroup, e) {}
+  :InitiateConnectionCommand(cuid, req, fileEntry, requestGroup, e) {}
 
 FtpInitiateConnectionCommand::~FtpInitiateConnectionCommand() {}
 
 Command* FtpInitiateConnectionCommand::createNextCommand
-(const std::deque<std::string>& resolvedAddresses,
+(const std::string& hostname, const std::string& addr, uint16_t port,
+ const std::deque<std::string>& resolvedAddresses,
  const SharedHandle<Request>& proxyRequest)
 {
   Command* command;
@@ -73,48 +76,54 @@ Command* FtpInitiateConnectionCommand::createNextCommand
       e->popPooledSocket(options, req->getHost(), req->getPort());
     std::string proxyMethod = resolveProxyMethod(req->getProtocol());
     if(pooledSocket.isNull()) {
-      logger->info(MSG_CONNECTING_TO_SERVER, cuid,
-		   proxyRequest->getHost().c_str(), proxyRequest->getPort());
+      logger->info(MSG_CONNECTING_TO_SERVER, cuid, addr.c_str(), port);
       socket.reset(new SocketCore());
-      socket->establishConnection(resolvedAddresses.front(),
-				  proxyRequest->getPort());
+      socket->establishConnection(addr, port);
       
       if(proxyMethod == V_GET) {
-	// Use GET for FTP via HTTP proxy.
-	req->setMethod(Request::METHOD_GET);
-	SharedHandle<HttpConnection> hc
-	  (new HttpConnection(cuid, socket, getOption().get()));
-	
-	HttpRequestCommand* c =
-	  new HttpRequestCommand(cuid, req, _requestGroup, hc, e, socket);
-	c->setProxyRequest(proxyRequest);
-	command = c;
+        // Use GET for FTP via HTTP proxy.
+        req->setMethod(Request::METHOD_GET);
+        SharedHandle<HttpConnection> hc
+          (new HttpConnection(cuid, socket, getOption().get()));
+        
+        HttpRequestCommand* c =
+          new HttpRequestCommand(cuid, req, _fileEntry,
+                                 _requestGroup, hc, e, socket);
+        c->setConnectedAddr(hostname, addr, port);
+        c->setProxyRequest(proxyRequest);
+        command = c;
       } else if(proxyMethod == V_TUNNEL) {
-	command = new FtpTunnelRequestCommand(cuid, req, _requestGroup, e,
-					      proxyRequest, socket);
+        FtpTunnelRequestCommand* c =
+          new FtpTunnelRequestCommand(cuid, req, _fileEntry,
+                                      _requestGroup, e,
+                                      proxyRequest, socket);
+        c->setConnectedAddr(hostname, addr, port);
+        command = c;
       } else {
-	// TODO
-	throw DL_ABORT_EX("ERROR");
+        // TODO
+        throw DL_ABORT_EX("ERROR");
       }
     } else {
       if(proxyMethod == V_TUNNEL) {
-	command =
-	  new FtpNegotiationCommand(cuid, req, _requestGroup, e, pooledSocket,
-				    FtpNegotiationCommand::SEQ_SEND_CWD,
-				    options["baseWorkingDir"]);
+        command =
+          new FtpNegotiationCommand(cuid, req, _fileEntry,
+                                    _requestGroup, e, pooledSocket,
+                                    FtpNegotiationCommand::SEQ_SEND_CWD,
+                                    options["baseWorkingDir"]);
       } else if(proxyMethod == V_GET) {
-	// Use GET for FTP via HTTP proxy.
-	req->setMethod(Request::METHOD_GET);
-	SharedHandle<HttpConnection> hc
-	  (new HttpConnection(cuid, pooledSocket, getOption().get()));
-	
-	HttpRequestCommand* c =
-	  new HttpRequestCommand(cuid, req, _requestGroup, hc, e, pooledSocket);
-	c->setProxyRequest(proxyRequest);
-	command = c;
+        // Use GET for FTP via HTTP proxy.
+        req->setMethod(Request::METHOD_GET);
+        SharedHandle<HttpConnection> hc
+          (new HttpConnection(cuid, pooledSocket, getOption().get()));
+        
+        HttpRequestCommand* c =
+          new HttpRequestCommand(cuid, req, _fileEntry,
+                                 _requestGroup, hc, e, pooledSocket);
+        c->setProxyRequest(proxyRequest);
+        command = c;
       } else {
-	// TODO
-	throw DL_ABORT_EX("ERROR");
+        // TODO
+        throw DL_ABORT_EX("ERROR");
       }
     }
   } else {
@@ -122,16 +131,20 @@ Command* FtpInitiateConnectionCommand::createNextCommand
     SharedHandle<SocketCore> pooledSocket =
       e->popPooledSocket(options, resolvedAddresses, req->getPort());
     if(pooledSocket.isNull()) {
-      logger->info(MSG_CONNECTING_TO_SERVER, cuid, req->getHost().c_str(),
-		   req->getPort());
+      logger->info(MSG_CONNECTING_TO_SERVER, cuid, addr.c_str(), port);
       socket.reset(new SocketCore());
-      socket->establishConnection(resolvedAddresses.front(), req->getPort());
-      command = new FtpNegotiationCommand(cuid, req, _requestGroup, e, socket);
+      socket->establishConnection(addr, port);
+      FtpNegotiationCommand* c =
+        new FtpNegotiationCommand(cuid, req, _fileEntry,
+                                  _requestGroup, e, socket);
+      c->setConnectedAddr(hostname, addr, port);
+      command = c;
     } else {
       command =
-	new FtpNegotiationCommand(cuid, req, _requestGroup, e, pooledSocket,
-				  FtpNegotiationCommand::SEQ_SEND_CWD,
-				  options["baseWorkingDir"]);
+        new FtpNegotiationCommand(cuid, req, _fileEntry,
+                                  _requestGroup, e, pooledSocket,
+                                  FtpNegotiationCommand::SEQ_SEND_CWD,
+                                  options["baseWorkingDir"]);
     }
   }
   return command;
