@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -151,7 +151,7 @@ void Peer::peerInterested(bool b)
   _res->peerInterested(b);
 }
   
-  // this peer should be choked
+// this peer should be choked
 bool Peer::chokingRequired() const
 {
   assert(_res);
@@ -335,18 +335,6 @@ void Peer::setAllBitfield() {
   _seeder = true;
 }
 
-void Peer::updateLatency(unsigned int latency)
-{
-  assert(_res);
-  _res->updateLatency(latency);
-}
-
-unsigned int Peer::getLatency() const
-{
-  assert(_res);
-  return _res->latency();
-}
-
 void Peer::startBadCondition()
 {
   _badConditionStartTime.reset();
