@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,7 +39,6 @@
 
 #include "PostDownloadHandler.h"
 #include "DownloadEngine.h"
-#include "DefaultSegmentManFactory.h"
 #include "SegmentMan.h"
 #include "NullProgressInfoFile.h"
 #include "Dependency.h"
@@ -114,12 +113,11 @@ int32_t RequestGroup::_gidCounter = 0;
 const std::string RequestGroup::ACCEPT_METALINK = "application/metalink+xml";
 
 RequestGroup::RequestGroup(const SharedHandle<Option>& option):
-  _gid(++_gidCounter),
+  _gid(newGID()),
   _option(new Option(*option.get())),
   _numConcurrentCommand(option->getAsInt(PREF_SPLIT)),
   _numStreamConnection(0),
   _numCommand(0),
-  _segmentManFactory(new DefaultSegmentManFactory(_option.get())),
   _saveControlFile(true),
   _progressInfoFile(new NullProgressInfoFile()),
   _preLocalFileCheckEnabled(true),
@@ -133,6 +131,7 @@ RequestGroup::RequestGroup(const SharedHandle<Option>& option):
   _inMemoryDownload(false),
   _maxDownloadSpeedLimit(option->getAsInt(PREF_MAX_DOWNLOAD_LIMIT)),
   _maxUploadSpeedLimit(option->getAsInt(PREF_MAX_UPLOAD_LIMIT)),
+  _belongsToGID(0),
   _logger(LogFactory::getInstance())
 {
   _fileAllocationEnabled = _option->get(PREF_FILE_ALLOCATION) != V_NONE;
@@ -149,13 +148,6 @@ RequestGroup::RequestGroup(const SharedHandle<Option>& option):
 
 RequestGroup::~RequestGroup() {}
 
-const SegmentManHandle& RequestGroup::initSegmentMan()
-{
-  _segmentMan = _segmentManFactory->createNewInstance(_downloadContext,
-						      _pieceStorage);
-  return _segmentMan;
-}
-
 bool RequestGroup::downloadFinished() const
 {
   if(_pieceStorage.isNull()) {
@@ -181,9 +173,9 @@ downloadresultcode::RESULT RequestGroup::downloadResult() const
   else {
     if (_lastUriResult.isNull()) {
       if(_haltReason == RequestGroup::USER_REQUEST) {
-	return downloadresultcode::IN_PROGRESS;
+        return downloadresultcode::IN_PROGRESS;
       } else {
-	return downloadresultcode::UNKNOWN_ERROR;
+        return downloadresultcode::UNKNOWN_ERROR;
       }
     } else {
       return _lastUriResult->getResult();
@@ -205,174 +197,177 @@ void RequestGroup::createInitialCommand
   {
     if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
       const BDE& torrentAttrs =
-	_downloadContext->getAttribute(bittorrent::BITTORRENT);
+        _downloadContext->getAttribute(bittorrent::BITTORRENT);
       bool metadataGetMode = !torrentAttrs.containsKey(bittorrent::METADATA);
       if(_option->getAsBool(PREF_DRY_RUN)) {
-	throw DOWNLOAD_FAILURE_EXCEPTION
-	  ("Cancel BitTorrent download in dry-run context.");
+        throw DOWNLOAD_FAILURE_EXCEPTION
+          ("Cancel BitTorrent download in dry-run context.");
       }
       SharedHandle<BtRegistry> btRegistry = e->getBtRegistry();
       if(!btRegistry->getDownloadContext
-	 (torrentAttrs[bittorrent::INFO_HASH].s()).isNull()) {
-	throw DOWNLOAD_FAILURE_EXCEPTION
-	  (StringFormat
-	   ("InfoHash %s is already registered.",
-	    bittorrent::getInfoHashString(_downloadContext).c_str()).str());
+         (torrentAttrs[bittorrent::INFO_HASH].s()).isNull()) {
+        throw DOWNLOAD_FAILURE_EXCEPTION
+          (StringFormat
+           ("InfoHash %s is already registered.",
+            bittorrent::getInfoHashString(_downloadContext).c_str()).str());
       }
       if(metadataGetMode) {
-	// Use UnknownLengthPieceStorage.
-	initPieceStorage();
+        // Use UnknownLengthPieceStorage.
+        initPieceStorage();
       } else {
-	if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
-	  throw DOWNLOAD_FAILURE_EXCEPTION
-	    (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-			  _downloadContext->getBasePath().c_str()).str());
-	}
-	initPieceStorage();
-	if(_downloadContext->getFileEntries().size() > 1) {
-	  _pieceStorage->setupFileFilter();
-	}
+        if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
+          throw DOWNLOAD_FAILURE_EXCEPTION
+            (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
+                          _downloadContext->getBasePath().c_str()).str());
+        }
+        initPieceStorage();
+        if(_downloadContext->getFileEntries().size() > 1) {
+          _pieceStorage->setupFileFilter();
+        }
       }
       
       SharedHandle<DefaultBtProgressInfoFile> progressInfoFile;
       if(!metadataGetMode) {
-	progressInfoFile.reset(new DefaultBtProgressInfoFile(_downloadContext,
-							     _pieceStorage,
-							     _option.get()));
+        progressInfoFile.reset(new DefaultBtProgressInfoFile(_downloadContext,
+                                                             _pieceStorage,
+                                                             _option.get()));
       }
         
       BtRuntimeHandle btRuntime(new BtRuntime());
       btRuntime->setMaxPeers(_option->getAsInt(PREF_BT_MAX_PEERS));
       _btRuntime = btRuntime;
       if(!progressInfoFile.isNull()) {
-	progressInfoFile->setBtRuntime(btRuntime);
+        progressInfoFile->setBtRuntime(btRuntime);
       }
 
       SharedHandle<DefaultPeerStorage> peerStorage
-	(new DefaultPeerStorage(_option.get()));
+        (new DefaultPeerStorage(_option.get()));
       peerStorage->setBtRuntime(btRuntime);
       peerStorage->setPieceStorage(_pieceStorage);
       _peerStorage = peerStorage;
       if(!progressInfoFile.isNull()) {
-	progressInfoFile->setPeerStorage(peerStorage);
+        progressInfoFile->setPeerStorage(peerStorage);
       }
 
       SharedHandle<DefaultBtAnnounce> btAnnounce
-	(new DefaultBtAnnounce(_downloadContext, _option.get()));
+        (new DefaultBtAnnounce(_downloadContext, _option.get()));
       btAnnounce->setBtRuntime(btRuntime);
       btAnnounce->setPieceStorage(_pieceStorage);
       btAnnounce->setPeerStorage(peerStorage);
       btAnnounce->setUserDefinedInterval
-	(_option->getAsInt(PREF_BT_TRACKER_INTERVAL));
+        (_option->getAsInt(PREF_BT_TRACKER_INTERVAL));
       btAnnounce->shuffleAnnounce();
       
+      assert(btRegistry->get(_gid).isNull());
       btRegistry->put(_gid,
-		      BtObject(_downloadContext,
-			       _pieceStorage,
-			       peerStorage,
-			       btAnnounce,
-			       btRuntime,
-			       (progressInfoFile.isNull()?
-				_progressInfoFile:
-				SharedHandle<BtProgressInfoFile>
-				(progressInfoFile))));
+                      BtObject(_downloadContext,
+                               _pieceStorage,
+                               peerStorage,
+                               btAnnounce,
+                               btRuntime,
+                               (progressInfoFile.isNull()?
+                                _progressInfoFile:
+                                SharedHandle<BtProgressInfoFile>
+                                (progressInfoFile))));
       if(metadataGetMode) {
-	if(_option->getAsBool(PREF_ENABLE_DHT)) {
-	  std::deque<Command*> dhtCommands;
-	  DHTSetup().setup(dhtCommands, e, _option.get());
-	  e->addCommand(dhtCommands);
-	} else {
-	  _logger->notice("For BitTorrent Magnet URI, enabling DHT is strongly"
-			  " recommended. See --enable-dht option.");
-	}
+        if(_option->getAsBool(PREF_ENABLE_DHT)) {
+          std::deque<Command*> dhtCommands;
+          DHTSetup().setup(dhtCommands, e, _option.get());
+          e->addCommand(dhtCommands);
+        } else {
+          _logger->notice("For BitTorrent Magnet URI, enabling DHT is strongly"
+                          " recommended. See --enable-dht option.");
+        }
 
-	SharedHandle<CheckIntegrityEntry> entry
-	  (new BtCheckIntegrityEntry(this));
-	entry->onDownloadIncomplete(commands, e);
-	
-	return;
+        SharedHandle<CheckIntegrityEntry> entry
+          (new BtCheckIntegrityEntry(this));
+        entry->onDownloadIncomplete(commands, e);
+        
+        return;
       }
 
       // Remove the control file if download file doesn't exist
       if(progressInfoFile->exists() && !_pieceStorage->getDiskAdaptor()->fileExists()) {
-	progressInfoFile->removeFile();
-	_logger->notice(MSG_REMOVED_DEFUNCT_CONTROL_FILE,
-			progressInfoFile->getFilename().c_str(),
-			_downloadContext->getBasePath().c_str());
+        progressInfoFile->removeFile();
+        _logger->notice(MSG_REMOVED_DEFUNCT_CONTROL_FILE,
+                        progressInfoFile->getFilename().c_str(),
+                        _downloadContext->getBasePath().c_str());
       }
       {
-	uint64_t actualFileSize = _pieceStorage->getDiskAdaptor()->size();
-	if(actualFileSize == _downloadContext->getTotalLength()) {
-	  // First, make DiskAdaptor read-only mode to allow the
-	  // program to seed file in read-only media.
-	  _pieceStorage->getDiskAdaptor()->enableReadOnly();
-	} else {
-	  // Open file in writable mode to allow the program
-	  // truncate the file to _downloadContext->getTotalLength()
-	  _logger->debug("File size not match. File is opened in writable mode."
-			 " Expected:%s Actual:%s",
-			 util::uitos(_downloadContext->getTotalLength()).c_str(),
-			 util::uitos(actualFileSize).c_str());
-	}
+        uint64_t actualFileSize = _pieceStorage->getDiskAdaptor()->size();
+        if(actualFileSize == _downloadContext->getTotalLength()) {
+          // First, make DiskAdaptor read-only mode to allow the
+          // program to seed file in read-only media.
+          _pieceStorage->getDiskAdaptor()->enableReadOnly();
+        } else {
+          // Open file in writable mode to allow the program
+          // truncate the file to _downloadContext->getTotalLength()
+          if(_logger->debug()) {
+            _logger->debug("File size not match. File is opened in writable"
+                           " mode. Expected:%s Actual:%s",
+                           util::uitos(_downloadContext->getTotalLength()).c_str(),
+                           util::uitos(actualFileSize).c_str());
+          }
+        }
       }
       // Call Load, Save and file allocation command here
       if(progressInfoFile->exists()) {
-	// load .aria2 file if it exists.
-	progressInfoFile->load();
-	_pieceStorage->getDiskAdaptor()->openFile();
+        // load .aria2 file if it exists.
+        progressInfoFile->load();
+        _pieceStorage->getDiskAdaptor()->openFile();
       } else {
-	if(_pieceStorage->getDiskAdaptor()->fileExists()) {
-	  if(!_option->getAsBool(PREF_CHECK_INTEGRITY) &&
-	     !_option->getAsBool(PREF_ALLOW_OVERWRITE) &&
-	     !_option->getAsBool(PREF_BT_SEED_UNVERIFIED)) {
-	    // TODO we need this->haltRequested = true?
-	    throw DOWNLOAD_FAILURE_EXCEPTION
-	      (StringFormat
-	       (MSG_FILE_ALREADY_EXISTS,
-		_downloadContext->getBasePath().c_str()).str());
-	  } else {
-	    _pieceStorage->getDiskAdaptor()->openFile();
-	  }
-	  if(_option->getAsBool(PREF_BT_SEED_UNVERIFIED)) {
-	    _pieceStorage->markAllPiecesDone();
-	  }
-	} else {
-	  _pieceStorage->getDiskAdaptor()->openFile();
-	}
+        if(_pieceStorage->getDiskAdaptor()->fileExists()) {
+          if(!_option->getAsBool(PREF_CHECK_INTEGRITY) &&
+             !_option->getAsBool(PREF_ALLOW_OVERWRITE) &&
+             !_option->getAsBool(PREF_BT_SEED_UNVERIFIED)) {
+            // TODO we need this->haltRequested = true?
+            throw DOWNLOAD_FAILURE_EXCEPTION
+              (StringFormat
+               (MSG_FILE_ALREADY_EXISTS,
+                _downloadContext->getBasePath().c_str()).str());
+          } else {
+            _pieceStorage->getDiskAdaptor()->openFile();
+          }
+          if(_option->getAsBool(PREF_BT_SEED_UNVERIFIED)) {
+            _pieceStorage->markAllPiecesDone();
+          }
+        } else {
+          _pieceStorage->getDiskAdaptor()->openFile();
+        }
       }
       _progressInfoFile = progressInfoFile;
 
       if(torrentAttrs[bittorrent::PRIVATE].i() == 0 &&
-	 _option->getAsBool(PREF_ENABLE_DHT)) {
-	std::deque<Command*> commands;
-	DHTSetup().setup(commands, e, _option.get());
-	e->addCommand(commands);
-	if(!torrentAttrs[bittorrent::NODES].empty() && DHTSetup::initialized()) {
-	  std::deque<std::pair<std::string, uint16_t> > entryPoints;
-	  const BDE& nodes = torrentAttrs[bittorrent::NODES];
-	  for(BDE::List::const_iterator i = nodes.listBegin();
-	      i != nodes.listEnd(); ++i) {
-	    std::pair<std::string, uint16_t> addr
-	      ((*i)[bittorrent::HOSTNAME].s(), (*i)[bittorrent::PORT].i());
-	    entryPoints.push_back(addr);
-	  }
-	  DHTEntryPointNameResolveCommand* command =
-	    new DHTEntryPointNameResolveCommand(e->newCUID(), e, entryPoints);
-	  command->setTaskQueue(DHTRegistry::_taskQueue);
-	  command->setTaskFactory(DHTRegistry::_taskFactory);
-	  command->setRoutingTable(DHTRegistry::_routingTable);
-	  command->setLocalNode(DHTRegistry::_localNode);
-	  e->commands.push_back(command);
-	}
+         _option->getAsBool(PREF_ENABLE_DHT)) {
+        std::deque<Command*> dhtCommands;
+        DHTSetup().setup(dhtCommands, e, _option.get());
+        e->addCommand(dhtCommands);
+        if(!torrentAttrs[bittorrent::NODES].empty() && DHTSetup::initialized()) {
+          std::deque<std::pair<std::string, uint16_t> > entryPoints;
+          const BDE& nodes = torrentAttrs[bittorrent::NODES];
+          for(BDE::List::const_iterator i = nodes.listBegin();
+              i != nodes.listEnd(); ++i) {
+            std::pair<std::string, uint16_t> addr
+              ((*i)[bittorrent::HOSTNAME].s(), (*i)[bittorrent::PORT].i());
+            entryPoints.push_back(addr);
+          }
+          DHTEntryPointNameResolveCommand* command =
+            new DHTEntryPointNameResolveCommand(e->newCUID(), e, entryPoints);
+          command->setTaskQueue(DHTRegistry::_taskQueue);
+          command->setTaskFactory(DHTRegistry::_taskFactory);
+          command->setRoutingTable(DHTRegistry::_routingTable);
+          command->setLocalNode(DHTRegistry::_localNode);
+          e->commands.push_back(command);
+        }
       }
       CheckIntegrityEntryHandle entry(new BtCheckIntegrityEntry(this));
       // --bt-seed-unverified=true is given and download has completed, skip
       // validation for piece hashes.
       if(_option->getAsBool(PREF_BT_SEED_UNVERIFIED) &&
-	 _pieceStorage->downloadFinished()) {
-	entry->onDownloadFinished(commands, e);
+         _pieceStorage->downloadFinished()) {
+        entry->onDownloadFinished(commands, e);
       } else {
-	processCheckIntegrityEntry(commands, entry, e);
+        processCheckIntegrityEntry(commands, entry, e);
       }
       return;
     }
@@ -392,34 +387,34 @@ void RequestGroup::createInitialCommand
   }else {
     if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
       throw DOWNLOAD_FAILURE_EXCEPTION
-	(StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-		      _downloadContext->getBasePath().c_str()).str());
+        (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
+                      _downloadContext->getBasePath().c_str()).str());
     }
     adjustFilename
       (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
-					(_downloadContext,
-					 SharedHandle<PieceStorage>(),
-					 _option.get())));
+                                        (_downloadContext,
+                                         SharedHandle<PieceStorage>(),
+                                         _option.get())));
     initPieceStorage();
     BtProgressInfoFileHandle infoFile
       (new DefaultBtProgressInfoFile(_downloadContext, _pieceStorage,
-				     _option.get()));
+                                     _option.get()));
     if(!infoFile->exists() && downloadFinishedByFileLength()) {
       _pieceStorage->markAllPiecesDone();
       _logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-		      _gid, _downloadContext->getBasePath().c_str());
+                      _gid, _downloadContext->getBasePath().c_str());
     } else {
       loadAndOpenFile(infoFile);
       SharedHandle<CheckIntegrityEntry> checkIntegrityEntry
-	(new StreamCheckIntegrityEntry(this));
+        (new StreamCheckIntegrityEntry(this));
       processCheckIntegrityEntry(commands, checkIntegrityEntry, e);
     }
   }
 }
 
 void RequestGroup::processCheckIntegrityEntry(std::deque<Command*>& commands,
-					      const CheckIntegrityEntryHandle& entry,
-					      DownloadEngine* e)
+                                              const CheckIntegrityEntryHandle& entry,
+                                              DownloadEngine* e)
 {
 #ifdef ENABLE_MESSAGE_DIGEST
   if(_option->getAsBool(PREF_CHECK_INTEGRITY) &&
@@ -443,35 +438,38 @@ void RequestGroup::processCheckIntegrityEntry(std::deque<Command*>& commands,
 
 void RequestGroup::initPieceStorage()
 {
+  SharedHandle<PieceStorage> tempPieceStorage;
   if(_downloadContext->knowsTotalLength()) {
 #ifdef ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
       (new DefaultPieceStorage(_downloadContext, _option.get()));
     if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
       if(isUriSuppliedForRequsetFileEntry
-	 (_downloadContext->getFileEntries().begin(),
-	  _downloadContext->getFileEntries().end())) {
-	// Use LongestSequencePieceSelector when HTTP/FTP/BitTorrent
-	// integrated downloads. Currently multi-file integrated
-	// download is not supported.
-	_logger->debug("Using LongestSequencePieceSelector");
-	ps->setPieceSelector
-	  (SharedHandle<PieceSelector>(new LongestSequencePieceSelector()));
+         (_downloadContext->getFileEntries().begin(),
+          _downloadContext->getFileEntries().end())) {
+        // Use LongestSequencePieceSelector when HTTP/FTP/BitTorrent
+        // integrated downloads. Currently multi-file integrated
+        // download is not supported.
+        if(_logger->debug()) {
+          _logger->debug("Using LongestSequencePieceSelector");
+        }
+        ps->setPieceSelector
+          (SharedHandle<PieceSelector>(new LongestSequencePieceSelector()));
       }
       if(_option->defined(PREF_BT_PRIORITIZE_PIECE)) {
-	std::vector<size_t> result;
-	util::parsePrioritizePieceRange
-	  (result, _option->get(PREF_BT_PRIORITIZE_PIECE),
-	   _downloadContext->getFileEntries(),
-	   _downloadContext->getPieceLength());
-	if(!result.empty()) {
-	  std::random_shuffle(result.begin(), result.end(),
-			      *(SimpleRandomizer::getInstance().get()));
-	  SharedHandle<PriorityPieceSelector> priSelector
-	    (new PriorityPieceSelector(ps->getPieceSelector()));
-	  priSelector->setPriorityPiece(result.begin(), result.end());
-	  ps->setPieceSelector(priSelector);
-	}
+        std::vector<size_t> result;
+        util::parsePrioritizePieceRange
+          (result, _option->get(PREF_BT_PRIORITIZE_PIECE),
+           _downloadContext->getFileEntries(),
+           _downloadContext->getPieceLength());
+        if(!result.empty()) {
+          std::random_shuffle(result.begin(), result.end(),
+                              *(SimpleRandomizer::getInstance().get()));
+          SharedHandle<PriorityPieceSelector> priSelector
+            (new PriorityPieceSelector(ps->getPieceSelector()));
+          priSelector->setPriorityPiece(result.begin(), result.end());
+          ps->setPieceSelector(priSelector);
+        }
       }
     }
 #else // !ENABLE_BITTORRENT
@@ -481,17 +479,21 @@ void RequestGroup::initPieceStorage()
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
     }
-    _pieceStorage = ps;
+    tempPieceStorage = ps;
   } else {
     UnknownLengthPieceStorageHandle ps
       (new UnknownLengthPieceStorage(_downloadContext, _option.get()));
     if(!_diskWriterFactory.isNull()) {
       ps->setDiskWriterFactory(_diskWriterFactory);
     }
-    _pieceStorage = ps;
+    tempPieceStorage = ps;
   }
-  _pieceStorage->initStorage();
-  initSegmentMan();
+  tempPieceStorage->initStorage();
+  SharedHandle<SegmentMan> tempSegmentMan
+    (new SegmentMan(_option.get(), _downloadContext, tempPieceStorage));
+
+  _pieceStorage = tempPieceStorage;
+  _segmentMan = tempSegmentMan;
 }
 
 bool RequestGroup::downloadFinishedByFileLength()
@@ -531,10 +533,10 @@ void RequestGroup::adjustFilename
     } else {
 #ifdef ENABLE_MESSAGE_DIGEST
       if(outfile.exists() && _option->getAsBool(PREF_CHECK_INTEGRITY)) {
-	// check-integrity existing file
+        // check-integrity existing file
       } else {
 #endif // ENABLE_MESSAGE_DIGEST
-	shouldCancelDownloadForSafety();
+        shouldCancelDownloadForSafety();
 #ifdef ENABLE_MESSAGE_DIGEST
       }
 #endif // ENABLE_MESSAGE_DIGEST
@@ -553,8 +555,8 @@ void RequestGroup::loadAndOpenFile(const BtProgressInfoFileHandle& progressInfoF
     if(progressInfoFile->exists() && !_pieceStorage->getDiskAdaptor()->fileExists()) {
       progressInfoFile->removeFile();
       _logger->notice(MSG_REMOVED_DEFUNCT_CONTROL_FILE,
-		      progressInfoFile->getFilename().c_str(),
-		      _downloadContext->getBasePath().c_str());
+                      progressInfoFile->getFilename().c_str(),
+                      _downloadContext->getBasePath().c_str());
     }
 
     if(progressInfoFile->exists()) {
@@ -563,18 +565,18 @@ void RequestGroup::loadAndOpenFile(const BtProgressInfoFileHandle& progressInfoF
     } else {
       File outfile(getFirstFilePath());    
       if(outfile.exists() && _option->getAsBool(PREF_CONTINUE) &&
-	 outfile.size() <= getTotalLength()) {
-	_pieceStorage->getDiskAdaptor()->openExistingFile();
-	_pieceStorage->markPiecesDone(outfile.size());
+         outfile.size() <= getTotalLength()) {
+        _pieceStorage->getDiskAdaptor()->openExistingFile();
+        _pieceStorage->markPiecesDone(outfile.size());
       } else {
 #ifdef ENABLE_MESSAGE_DIGEST
-	if(outfile.exists() && _option->getAsBool(PREF_CHECK_INTEGRITY)) {
-	  _pieceStorage->getDiskAdaptor()->openExistingFile();
-	} else {
+        if(outfile.exists() && _option->getAsBool(PREF_CHECK_INTEGRITY)) {
+          _pieceStorage->getDiskAdaptor()->openExistingFile();
+        } else {
 #endif // ENABLE_MESSAGE_DIGEST
-	  _pieceStorage->getDiskAdaptor()->initAndOpenFile();
+          _pieceStorage->getDiskAdaptor()->initAndOpenFile();
 #ifdef ENABLE_MESSAGE_DIGEST
-	}
+        }
 #endif // ENABLE_MESSAGE_DIGEST
       }
     }
@@ -595,16 +597,16 @@ void RequestGroup::shouldCancelDownloadForSafety()
   if(outfile.exists()) {
     if(_option->getAsBool(PREF_AUTO_FILE_RENAMING)) {
       if(tryAutoFileRenaming()) {
-	_logger->notice(MSG_FILE_RENAMED, getFirstFilePath().c_str());
+        _logger->notice(MSG_FILE_RENAMED, getFirstFilePath().c_str());
       } else {
-	throw DOWNLOAD_FAILURE_EXCEPTION
-	  (StringFormat("File renaming failed: %s",
-			getFirstFilePath().c_str()).str());
+        throw DOWNLOAD_FAILURE_EXCEPTION
+          (StringFormat("File renaming failed: %s",
+                        getFirstFilePath().c_str()).str());
       }
     } else {
       throw DOWNLOAD_FAILURE_EXCEPTION
-	(StringFormat(MSG_FILE_ALREADY_EXISTS,
-		      getFirstFilePath().c_str()).str());
+        (StringFormat(MSG_FILE_ALREADY_EXISTS,
+                      getFirstFilePath().c_str()).str());
     }
   }
 }
@@ -616,7 +618,7 @@ bool RequestGroup::tryAutoFileRenaming()
     return false;
   }
   for(unsigned int i = 1; i < 10000; ++i) {
-    File newfile(strconcat(filepath, ".", util::uitos(i)));
+    File newfile(strconcat(filepath, A2STR::DOT_C, util::uitos(i)));
     File ctrlfile(newfile.getPath()+DefaultBtProgressInfoFile::getSuffix());
     if(!newfile.exists() || (newfile.exists() && ctrlfile.exists())) {
       _downloadContext->getFirstFileEntry()->setPath(newfile.getPath());
@@ -627,14 +629,14 @@ bool RequestGroup::tryAutoFileRenaming()
 }
 
 void RequestGroup::createNextCommandWithAdj(std::deque<Command*>& commands,
-					    DownloadEngine* e, int numAdj)
+                                            DownloadEngine* e, int numAdj)
 {
   int numCommand;
   if(getTotalLength() == 0) {
     numCommand = 1+numAdj;
   } else {
     numCommand = std::min(_downloadContext->getNumPieces(),
-			  _numConcurrentCommand);
+                          _numConcurrentCommand);
     numCommand += numAdj;
   }
   if(numCommand > 0) {
@@ -643,8 +645,8 @@ void RequestGroup::createNextCommandWithAdj(std::deque<Command*>& commands,
 }
 
 void RequestGroup::createNextCommand(std::deque<Command*>& commands,
-				     DownloadEngine* e,
-				     unsigned int numCommand)
+                                     DownloadEngine* e,
+                                     unsigned int numCommand)
 {
   for(; numCommand--; ) {
     Command* command = new CreateRequestCommand(e->newCUID(), this, e);
@@ -693,20 +695,20 @@ uint64_t RequestGroup::getCompletedLength() const
 }
 
 void RequestGroup::validateFilename(const std::string& expectedFilename,
-				    const std::string& actualFilename) const
+                                    const std::string& actualFilename) const
 {
   if(expectedFilename.empty()) {
     return;
   }
   if(expectedFilename != actualFilename) {
     throw DL_ABORT_EX(StringFormat(EX_FILENAME_MISMATCH,
-				 expectedFilename.c_str(),
-				 actualFilename.c_str()).str());
+                                   expectedFilename.c_str(),
+                                   actualFilename.c_str()).str());
   }
 }
 
 void RequestGroup::validateTotalLength(uint64_t expectedTotalLength,
-				       uint64_t actualTotalLength) const
+                                       uint64_t actualTotalLength) const
 {
   if(expectedTotalLength <= 0) {
     return;
@@ -714,8 +716,8 @@ void RequestGroup::validateTotalLength(uint64_t expectedTotalLength,
   if(expectedTotalLength != actualTotalLength) {
     throw DL_ABORT_EX
       (StringFormat(EX_SIZE_MISMATCH,
-		    util::itos(expectedTotalLength, true).c_str(),
-		    util::itos(actualTotalLength, true).c_str()).str());
+                    util::itos(expectedTotalLength, true).c_str(),
+                    util::itos(actualTotalLength, true).c_str()).str());
   }
 }
 
@@ -807,41 +809,49 @@ void RequestGroup::releaseRuntimeResource(DownloadEngine* e)
 
 void RequestGroup::preDownloadProcessing()
 {
-  _logger->debug("Finding PreDownloadHandler for path %s.",
-		 getFirstFilePath().c_str());
+  if(_logger->debug()) {
+    _logger->debug("Finding PreDownloadHandler for path %s.",
+                   getFirstFilePath().c_str());
+  }
   try {
     for(PreDownloadHandlers::const_iterator itr = _preDownloadHandlers.begin();
-	itr != _preDownloadHandlers.end(); ++itr) {
+        itr != _preDownloadHandlers.end(); ++itr) {
       if((*itr)->canHandle(this)) {
-	(*itr)->execute(this);
-	return;
+        (*itr)->execute(this);
+        return;
       }
     }
   } catch(RecoverableException& ex) {
     _logger->error(EX_EXCEPTION_CAUGHT, ex);
     return;
   }
-  _logger->debug("No PreDownloadHandler found.");
+  if(_logger->debug()) {
+    _logger->debug("No PreDownloadHandler found.");
+  }
   return;
 }
 
 void RequestGroup::postDownloadProcessing
 (std::deque<SharedHandle<RequestGroup> >& groups)
 {
-  _logger->debug("Finding PostDownloadHandler for path %s.",
-		 getFirstFilePath().c_str());
+  if(_logger->debug()) {
+    _logger->debug("Finding PostDownloadHandler for path %s.",
+                   getFirstFilePath().c_str());
+  }
   try {
     for(PostDownloadHandlers::const_iterator itr = _postDownloadHandlers.begin();
-	itr != _postDownloadHandlers.end(); ++itr) {
+        itr != _postDownloadHandlers.end(); ++itr) {
       if((*itr)->canHandle(this)) {
-	(*itr)->getNextRequestGroups(groups, this);
-	return;
+        (*itr)->getNextRequestGroups(groups, this);
+        return;
       }
     }
   } catch(RecoverableException& ex) {
     _logger->error(EX_EXCEPTION_CAUGHT, ex);
   }
-  _logger->debug("No PostDownloadHandler found.");
+  if(_logger->debug()) {
+    _logger->debug("No PostDownloadHandler found.");
+  }
 }
 
 void RequestGroup::initializePreDownloadHandler()
@@ -882,11 +892,6 @@ bool RequestGroup::isDependencyResolved()
   return _dependency->resolve();
 }
 
-void RequestGroup::setSegmentManFactory(const SegmentManFactoryHandle& segmentManFactory)
-{
-  _segmentManFactory = segmentManFactory;
-}
-
 void RequestGroup::dependsOn(const DependencyHandle& dep)
 {
   _dependency = dep;
@@ -951,17 +956,19 @@ DownloadResultHandle RequestGroup::createDownloadResult() const
   return
     SharedHandle<DownloadResult>
     (new DownloadResult(_gid,
-			_downloadContext->getFileEntries(),
-			_inMemoryDownload,
-			sessionDownloadLength,
-			_downloadContext->calculateSessionTime(),
-			downloadResult()));
+                        _downloadContext->getFileEntries(),
+                        _inMemoryDownload,
+                        sessionDownloadLength,
+                        _downloadContext->calculateSessionTime(),
+                        downloadResult(),
+                        _followedByGIDs,
+                        _belongsToGID));
 }
   
 void RequestGroup::reportDownloadFinished()
 {
   _logger->notice(MSG_FILE_DOWNLOAD_COMPLETED,
-		  _downloadContext->getBasePath().c_str());
+                  _downloadContext->getBasePath().c_str());
   _uriSelector->resetCounters();
 #ifdef ENABLE_BITTORRENT
   if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
@@ -971,9 +978,9 @@ void RequestGroup::reportDownloadFinished()
     const BDE& attrs = _downloadContext->getAttribute(bittorrent::BITTORRENT);
     if(attrs.containsKey(bittorrent::METADATA)) {
       _logger->notice(MSG_SHARE_RATIO_REPORT,
-		      shareRatio,
-		      util::abbrevSize(stat.getAllTimeUploadLength()).c_str(),
-		      util::abbrevSize(getCompletedLength()).c_str());
+                      shareRatio,
+                      util::abbrevSize(stat.getAllTimeUploadLength()).c_str(),
+                      util::abbrevSize(getCompletedLength()).c_str());
     }
   }
 #endif // ENABLE_BITTORRENT
@@ -989,7 +996,7 @@ void RequestGroup::addAcceptType(const std::string& type)
 void RequestGroup::removeAcceptType(const std::string& type)
 {
   _acceptTypes.erase(std::remove(_acceptTypes.begin(), _acceptTypes.end(), type),
-		     _acceptTypes.end());
+                     _acceptTypes.end());
 }
 
 void RequestGroup::setURISelector(const SharedHandle<URISelector>& uriSelector)
@@ -1002,11 +1009,11 @@ void RequestGroup::applyLastModifiedTimeToLocalFiles()
   if(!_pieceStorage.isNull() && _lastModifiedTime.good()) {
     time_t t = _lastModifiedTime.getTime();
     _logger->info("Applying Last-Modified time: %s in local time zone",
-		  ctime(&t));
+                  ctime(&t));
     size_t n =
       _pieceStorage->getDiskAdaptor()->utime(Time(), _lastModifiedTime);
     _logger->info("Last-Modified attrs of %lu files were updated.",
-		  static_cast<unsigned long>(n));
+                  static_cast<unsigned long>(n));
   }
 }
 
@@ -1022,7 +1029,8 @@ void RequestGroup::increaseAndValidateFileNotFoundCount()
   ++_fileNotFoundCount;
   const unsigned int maxCount = _option->getAsInt(PREF_MAX_FILE_NOT_FOUND);
   if(maxCount > 0 && _fileNotFoundCount >= maxCount &&
-     _segmentMan->calculateSessionDownloadLength() == 0) {
+     (_segmentMan.isNull() ||
+      _segmentMan->calculateSessionDownloadLength() == 0)) {
     throw DOWNLOAD_FAILURE_EXCEPTION2
       (StringFormat("Reached max-file-not-found count=%u", maxCount).str(),
        downloadresultcode::MAX_FILE_NOT_FOUND);
@@ -1078,4 +1086,12 @@ void RequestGroup::setDownloadContext
   }
 }
 
+int32_t RequestGroup::newGID()
+{
+  if(_gidCounter == INT32_MAX) {
+    _gidCounter = 0;
+  }
+  return ++_gidCounter;
+}
+
 } // namespace aria2
