@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -34,6 +34,9 @@
 /* copyright --> */
 #include "SelectEventPoll.h"
 
+#ifdef __MINGW32__
+# include <cassert>
+#endif // __MINGW32__
 #include <cstring>
 #include <algorithm>
 #include <numeric>
@@ -115,7 +118,7 @@ int SelectEventPoll::SocketEntry::getEvents()
 {
   return
     std::accumulate(_commandEvents.begin(), _commandEvents.end(), 0,
-		    accumulateEvent);
+                    accumulateEvent);
 }
 
 #ifdef ENABLE_ASYNC_DNS
@@ -148,10 +151,19 @@ void SelectEventPoll::AsyncNameResolverEntry::process
 
 SelectEventPoll::SelectEventPoll():_logger(LogFactory::getInstance())
 {
+#ifdef __MINGW32__
+  _dummySocket = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
+  assert(_dummySocket != (sock_t)-1);
+#endif // __MINGW32__
   updateFdSet();
 }
 
-SelectEventPoll::~SelectEventPoll() {}
+SelectEventPoll::~SelectEventPoll()
+{
+#ifdef __MINGW32__
+  ::closesocket(_dummySocket);
+#endif // __MINGW32__
+}
 
 void SelectEventPoll::poll(const struct timeval& tv)
 {
@@ -160,6 +172,11 @@ void SelectEventPoll::poll(const struct timeval& tv)
   
   memcpy(&rfds, &_rfdset, sizeof(fd_set));
   memcpy(&wfds, &_wfdset, sizeof(fd_set));
+#ifdef __MINGW32__
+  fd_set efds;
+  FD_ZERO(&efds);
+  FD_SET(_dummySocket, &efds);
+#endif // __MINGW32__
 #ifdef ENABLE_ASYNC_DNS
 
   for(std::deque<SharedHandle<AsyncNameResolverEntry> >::iterator itr =
@@ -177,7 +194,11 @@ void SelectEventPoll::poll(const struct timeval& tv)
   int retval;
   do {
     struct timeval ttv = tv;
+#ifdef __MINGW32__
+    retval = select(_fdmax+1, &rfds, &wfds, &efds, &ttv);
+#else // !__MINGW32__
     retval = select(_fdmax+1, &rfds, &wfds, NULL, &ttv);
+#endif // !__MINGW32__
   } while(retval == -1 && errno == EINTR);
   if(retval > 0) {
     for(std::deque<SharedHandle<SocketEntry> >::iterator i =
@@ -204,7 +225,11 @@ void SelectEventPoll::poll(const struct timeval& tv)
 
 void SelectEventPoll::updateFdSet()
 {
+#ifdef __MINGW32__
+  _fdmax = _dummySocket;
+#else // !__MINGW32__
   _fdmax = 0;
+#endif // !__MINGW32__
   FD_ZERO(&_rfdset);
   FD_ZERO(&_wfdset);
   for(std::deque<SharedHandle<SocketEntry> >::iterator i =
@@ -224,7 +249,7 @@ void SelectEventPoll::updateFdSet()
 }
 
 bool SelectEventPoll::addEvents(sock_t socket, Command* command,
-				EventPoll::EventType events)
+                                EventPoll::EventType events)
 {
   SharedHandle<SocketEntry> socketEntry(new SocketEntry(socket));
   std::deque<SharedHandle<SocketEntry> >::iterator i =
@@ -238,7 +263,10 @@ bool SelectEventPoll::addEvents(sock_t socket, Command* command,
   }
   updateFdSet();
   if(r == -1) {
-    _logger->debug("Failed to add socket event %d:%s", socket, strerror(errno));
+    if(_logger->debug()) {
+      _logger->debug("Failed to add socket event %d:%s",
+                     socket, strerror(errno));
+    }
     return false;
   } else {
     return true;
@@ -246,7 +274,7 @@ bool SelectEventPoll::addEvents(sock_t socket, Command* command,
 }
 
 bool SelectEventPoll::deleteEvents(sock_t socket, Command* command,
-				   EventPoll::EventType events)
+                                   EventPoll::EventType events)
 {
   SharedHandle<SocketEntry> socketEntry(new SocketEntry(socket));
   std::deque<SharedHandle<SocketEntry> >::iterator i =
@@ -259,13 +287,17 @@ bool SelectEventPoll::deleteEvents(sock_t socket, Command* command,
     }
     updateFdSet();
     if(r == -1) {
-      _logger->debug("Failed to delete socket event:%s", strerror(errno));
+      if(_logger->debug()) {
+        _logger->debug("Failed to delete socket event:%s", strerror(errno));
+      }
       return false;
     } else {
       return true;
     }
   } else {
-    _logger->debug("Socket %d is not found in SocketEntries.", socket);
+    if(_logger->debug()) {
+      _logger->debug("Socket %d is not found in SocketEntries.", socket);
+    }
     return false;
   }
 }
