@@ -59,6 +59,8 @@
 # include "TLSContext.h"
 #endif // ENABLE_SSL
 
+namespace aria2 {
+
 #ifndef __MINGW32__
 # define SOCKET_ERRNO (errno)
 #else
@@ -67,9 +69,22 @@
 
 #ifdef __MINGW32__
 # define A2_EINPROGRESS WSAEWOULDBLOCK
-#else
+# define A2_EWOULDBLOCK WSAEWOULDBLOCK
+# define A2_EINTR WSAEINTR
+# define A2_WOULDBLOCK(e) (e == WSAEWOULDBLOCK)
+#else // !__MINGW32__
 # define A2_EINPROGRESS EINPROGRESS
-#endif // __MINGW32__
+# ifndef EWOULDBLOCK
+#  define EWOULDBLOCK EAGAIN
+# endif // EWOULDBLOCK
+# define A2_EWOULDBLOCK EWOULDBLOCK
+# define A2_EINTR EINTR
+# if EWOULDBLOCK == EAGAIN
+#  define A2_WOULDBLOCK(e) (e == EWOULDBLOCK)
+# else // EWOULDBLOCK != EAGAIN
+#  define A2_WOULDBLOCK(e) (e == EWOULDBLOCK || e == EAGAIN)
+# endif // EWOULDBLOCK != EAGAIN
+#endif // !__MINGW32__
 
 #ifdef __MINGW32__
 # define CLOSE(X) ::closesocket(X)
@@ -77,7 +92,32 @@
 # define CLOSE(X) while(close(X) == -1 && errno == EINTR)
 #endif // __MINGW32__
 
-namespace aria2 {
+static const char *errorMsg(const int err)
+{
+#ifndef __MINGW32__
+  return strerror(err);
+#else
+  static char buf[256];
+  if (FormatMessage(
+                    FORMAT_MESSAGE_FROM_SYSTEM |
+                    FORMAT_MESSAGE_IGNORE_INSERTS,
+                    NULL,
+                    err,
+                    MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
+                    (LPTSTR) &buf,
+                    sizeof(buf),
+                    NULL
+                    ) == 0) {
+    snprintf(buf, sizeof(buf), EX_SOCKET_UNKNOWN_ERROR, err, err);
+  }
+  return buf;
+#endif // __MINGW32__
+}
+
+static const char *errorMsg()
+{
+  return errorMsg(SOCKET_ERRNO);
+}
 
 #ifdef HAVE_EPOLL
 SocketCore::PollMethod SocketCore::_pollMethod = SocketCore::POLL_METHOD_EPOLL;
@@ -180,7 +220,9 @@ static sock_t bindInternal(int family, int socktype, int protocol,
     return -1;
   }
   if(::bind(fd, addr, addrlen) == -1) {
-    LogFactory::getInstance()->debug(EX_SOCKET_BIND, strerror(errno));
+    if(LogFactory::getInstance()->debug()) {
+      LogFactory::getInstance()->debug(EX_SOCKET_BIND, errorMsg());
+    }
     CLOSE(fd);
     return -1;
   }
@@ -207,7 +249,7 @@ static sock_t bindTo
       return fd;
     }
   }
-  error = strerror(errno);
+  error = errorMsg();
   return -1;
 }
 
@@ -253,7 +295,7 @@ void SocketCore::bind(const struct sockaddr* addr, socklen_t addrlen)
   if(fd != (sock_t)-1) {
     sockfd = fd;
   } else {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BIND, strerror(errno)).str());
+    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BIND, errorMsg()).str());
   }
 }
 
@@ -269,7 +311,7 @@ SocketCore* SocketCore::acceptConnection() const
   struct sockaddr_storage sockaddr;
   socklen_t len = sizeof(sockaddr);
   sock_t fd;
-  while((fd = accept(sockfd, reinterpret_cast<struct sockaddr*>(&sockaddr), &len)) == (sock_t) -1 && SOCKET_ERRNO == EINTR);
+  while((fd = accept(sockfd, reinterpret_cast<struct sockaddr*>(&sockaddr), &len)) == (sock_t) -1 && SOCKET_ERRNO == A2_EINTR);
   if(fd == (sock_t) -1) {
     throw DL_ABORT_EX(StringFormat(EX_SOCKET_ACCEPT, errorMsg()).str());
   }
@@ -328,7 +370,9 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
             const_iterator i = _bindAddrs.begin(); i != _bindAddrs.end(); ++i) {
         if(::bind(fd,reinterpret_cast<const struct sockaddr*>(&(*i).first),
                   (*i).second) == -1) {
-          LogFactory::getInstance()->debug(EX_SOCKET_BIND, strerror(errno));
+          if(LogFactory::getInstance()->debug()) {
+            LogFactory::getInstance()->debug(EX_SOCKET_BIND, errorMsg());
+          }
         } else {
           bindSuccess = true;
           break;
@@ -355,7 +399,7 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
   }
   if(sockfd == (sock_t) -1) {
     throw DL_ABORT_EX(StringFormat(EX_SOCKET_CONNECT, host.c_str(),
-                                   strerror(errno)).str());
+                                   errorMsg()).str());
   }
 }
 
@@ -475,7 +519,7 @@ bool SocketCore::isWritable(time_t timeout)
         // time out
         return false;
       } else {
-        if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == EINTR) {
+        if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == A2_EINTR) {
           return false;
         } else {
           throw DL_RETRY_EX(StringFormat(EX_SOCKET_CHECK_WRITABLE, errorMsg()).str());
@@ -528,7 +572,7 @@ bool SocketCore::isReadable(time_t timeout)
         // time out
         return false;
       } else {
-        if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == EINTR) {
+        if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == A2_EINTR) {
           return false;
         } else {
           throw DL_RETRY_EX(StringFormat(EX_SOCKET_CHECK_READABLE, errorMsg()).str());
@@ -574,9 +618,9 @@ ssize_t SocketCore::writeData(const char* data, size_t len)
   _wantWrite = false;
 
   if(!secure) {
-    while((ret = send(sockfd, data, len, 0)) == -1 && SOCKET_ERRNO == EINTR);
+    while((ret = send(sockfd, data, len, 0)) == -1 && SOCKET_ERRNO == A2_EINTR);
     if(ret == -1) {
-      if(SOCKET_ERRNO == EAGAIN) {
+      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
         _wantWrite = true;
         ret = 0;
       } else {
@@ -586,11 +630,6 @@ ssize_t SocketCore::writeData(const char* data, size_t len)
   } else {
 #ifdef HAVE_LIBSSL
     ret = SSL_write(ssl, data, len);
-    if(ret == 0) {
-      throw DL_RETRY_EX
-        (StringFormat
-         (EX_SOCKET_SEND, ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
-    }
     if(ret < 0) {
       ret = sslHandleEAGAIN(ret);
     }
@@ -622,10 +661,10 @@ void SocketCore::readData(char* data, size_t& len)
   _wantWrite = false;
 
   if(!secure) {    
-    while((ret = recv(sockfd, data, len, 0)) == -1 && SOCKET_ERRNO == EINTR);
+    while((ret = recv(sockfd, data, len, 0)) == -1 && SOCKET_ERRNO == A2_EINTR);
     
     if(ret == -1) {
-      if(SOCKET_ERRNO == EAGAIN) {
+      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
         _wantRead = true;
         ret = 0;
       } else {
@@ -637,11 +676,6 @@ void SocketCore::readData(char* data, size_t& len)
     // for SSL
     // TODO handling len == 0 case required
     ret = SSL_read(ssl, data, len);
-    if(ret == 0) {
-      throw DL_RETRY_EX
-        (StringFormat
-         (EX_SOCKET_RECV, ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
-    }
     if(ret < 0) {
       ret = sslHandleEAGAIN(ret);
     }
@@ -673,9 +707,10 @@ void SocketCore::peekData(char* data, size_t& len)
   _wantWrite = false;
 
   if(!secure) {
-    while((ret = recv(sockfd, data, len, MSG_PEEK)) == -1 && SOCKET_ERRNO == EINTR);
+    while((ret = recv(sockfd, data, len, MSG_PEEK)) == -1 &&
+          SOCKET_ERRNO == A2_EINTR);
     if(ret == -1) {
-      if(SOCKET_ERRNO == EAGAIN) {
+      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
         _wantRead = true;
         ret = 0;
       } else {
@@ -687,11 +722,6 @@ void SocketCore::peekData(char* data, size_t& len)
     // for SSL
     // TODO handling len == 0 case required
     ret = SSL_peek(ssl, data, len);
-    if(ret == 0) {
-      throw DL_RETRY_EX
-        (StringFormat(EX_SOCKET_PEEK,
-                      ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
-    }
     if(ret < 0) {
       ret = sslHandleEAGAIN(ret);
     }
@@ -1010,38 +1040,6 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
   }
 }
 
-/* static */ int SocketCore::error()
-{
-  return SOCKET_ERRNO;
-}
-
-/* static */ const char *SocketCore::errorMsg()
-{
-  return errorMsg(SOCKET_ERRNO);
-}
-
-/* static */ const char *SocketCore::errorMsg(const int err)
-{
-#ifndef __MINGW32__
-  return strerror(err);
-#else
-  static char buf[256];
-  if (FormatMessage(
-                    FORMAT_MESSAGE_FROM_SYSTEM |
-                    FORMAT_MESSAGE_IGNORE_INSERTS,
-                    NULL,
-                    err,
-                    MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
-                    (LPTSTR) &buf,
-                    sizeof(buf),
-                    NULL
-                    ) == 0) {
-    snprintf(buf, sizeof(buf), EX_SOCKET_UNKNOWN_ERROR, err, err);
-  }
-  return buf;
-#endif // __MINGW32__
-}
-
 ssize_t SocketCore::writeData(const char* data, size_t len,
                               const std::string& host, uint16_t port)
 {
@@ -1059,11 +1057,12 @@ ssize_t SocketCore::writeData(const char* data, size_t len,
   struct addrinfo* rp;
   ssize_t r = -1;
   for(rp = res; rp; rp = rp->ai_next) {
-    while((r = sendto(sockfd, data, len, 0, rp->ai_addr, rp->ai_addrlen)) == -1 && EINTR == SOCKET_ERRNO);
+    while((r = sendto(sockfd, data, len, 0, rp->ai_addr, rp->ai_addrlen)) == -1
+          && A2_EINTR == SOCKET_ERRNO);
     if(r == static_cast<ssize_t>(len)) {
       break;
     }
-    if(r == -1 && SOCKET_ERRNO == EAGAIN) {
+    if(r == -1 && A2_WOULDBLOCK(SOCKET_ERRNO)) {
       _wantWrite = true;
       r = 0;
       break;
@@ -1086,9 +1085,9 @@ ssize_t SocketCore::readDataFrom(char* data, size_t len,
   struct sockaddr* addrp = reinterpret_cast<struct sockaddr*>(&sockaddr);
   ssize_t r;
   while((r = recvfrom(sockfd, data, len, 0, addrp, &sockaddrlen)) == -1 &&
-        EINTR == SOCKET_ERRNO);
+        A2_EINTR == SOCKET_ERRNO);
   if(r == -1) {
-    if(SOCKET_ERRNO == EAGAIN) {
+    if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
       _wantRead = true;
       r = 0;
     } else {
@@ -1142,14 +1141,16 @@ void SocketCore::useSelect()
 void SocketCore::bindAddress(const std::string& iface)
 {
   std::vector<std::pair<struct sockaddr_storage, socklen_t> > bindAddrs;
-  LogFactory::getInstance()->debug("Finding interface %s", iface.c_str());
+  if(LogFactory::getInstance()->debug()) {
+    LogFactory::getInstance()->debug("Finding interface %s", iface.c_str());
+  }
 #ifdef HAVE_GETIFADDRS
   // First find interface in interface addresses
   struct ifaddrs* ifaddr = 0;
   if(getifaddrs(&ifaddr) == -1) {
     throw DL_ABORT_EX
       (StringFormat(MSG_INTERFACE_NOT_FOUND,
-                    iface.c_str(), strerror(errno)).str());
+                    iface.c_str(), errorMsg()).str());
   } else {
     auto_delete<struct ifaddrs*> ifaddrDeleter(ifaddr, freeifaddrs);
     for(struct ifaddrs* ifa = ifaddr; ifa; ifa = ifa->ifa_next) {
@@ -1229,7 +1230,9 @@ void SocketCore::bindAddress(const std::string& iface)
                       host, NI_MAXHOST, 0, NI_MAXSERV,
                       NI_NUMERICHOST);
       if(s == 0) {
-        LogFactory::getInstance()->debug("Sockets will bind to %s", host);
+        if(LogFactory::getInstance()->debug()) {
+          LogFactory::getInstance()->debug("Sockets will bind to %s", host);
+        }
       }
     }
   }
