@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -44,6 +44,7 @@
 #include <string>
 #include <cstdlib>
 #include <utility>
+#include <vector>
 
 #ifdef HAVE_LIBSSL
 // for SSL
@@ -92,6 +93,8 @@ private:
 
   static int _protocolFamily;
 
+  static std::vector<std::pair<struct sockaddr_storage, socklen_t> > _bindAddrs;
+
   bool blocking;
   int secure;
 
@@ -124,6 +127,8 @@ private:
 
   void init();
 
+  void bind(const struct sockaddr* addr, socklen_t addrlen);
+
 #ifdef HAVE_EPOLL
 
   void initEPOLL();
@@ -131,10 +136,6 @@ private:
 #endif // HAVE_EPOLL
 
   SocketCore(sock_t sockfd, int sockType);
-
-  static int error();
-  static const char *errorMsg();
-  static const char *errorMsg(const int err);
 public:
   SocketCore(int sockType = SOCK_STREAM);
   ~SocketCore();
@@ -239,11 +240,11 @@ public:
   }
 
   ssize_t writeData(const char* data, size_t len,
-		    const std::string& host, uint16_t port);
+                    const std::string& host, uint16_t port);
 
   ssize_t writeData(const unsigned char* data, size_t len,
-		    const std::string& host,
-		    uint16_t port)
+                    const std::string& host,
+                    uint16_t port)
   {
     return writeData(reinterpret_cast<const char*>(data), len, host, port);
   }
@@ -272,12 +273,12 @@ public:
   }
 
   ssize_t readDataFrom(char* data, size_t len,
-		       std::pair<std::string /* numerichost */,
-		       uint16_t /* port */>& sender);
+                       std::pair<std::string /* numerichost */,
+                       uint16_t /* port */>& sender);
 
   ssize_t readDataFrom(unsigned char* data, size_t len,
-		       std::pair<std::string /* numerichost */,
-		       uint16_t /* port */>& sender)
+                       std::pair<std::string /* numerichost */,
+                       uint16_t /* port */>& sender)
   {
     return readDataFrom(reinterpret_cast<char*>(data), len, sender);
   }
@@ -349,8 +350,30 @@ public:
   {
     _protocolFamily = protocolFamily;
   }
+
+  // Bind socket to interface. interface may be specified as a
+  // hostname, IP address or interface name like eth0.  If the given
+  // interface is not found or binding socket is failed, exception
+  // will be thrown.  Set _protocolFamily before calling this function
+  // if you limit protocol family.
+  //
+  // We cannot use interface as an argument because it is a reserved
+  // keyword in MSVC.
+  static void bindAddress(const std::string& iface);
 };
 
+// Set default ai_flags. hints.ai_flags is initialized with this
+// value.
+void setDefaultAIFlags(int flags);
+
+// Wrapper function for getaddrinfo(). The value
+// flags|DEFAULT_AI_FLAGS is used as ai_flags.  You can override
+// DEFAULT_AI_FLAGS value by calling setDefaultAIFlags() with new
+// flags.
+int callGetaddrinfo
+(struct addrinfo** resPtr, const char* host, const char* service, int family,
+ int sockType, int flags, int protocol);
+
 } // namespace aria2
 
 #endif // _D_SOCKET_CORE_H_
