@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -47,7 +47,6 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "util.h"
-#include "BitfieldManFactory.h"
 #include "FeatureConfig.h"
 #include "MultiUrlRequestInfo.h"
 #include "SimpleRandomizer.h"
@@ -94,7 +93,8 @@ SharedHandle<StatCalc> getStatCalc(const SharedHandle<Option>& op)
   if(op->getAsBool(PREF_QUIET)) {
     statCalc.reset(new NullStatCalc());
   } else {
-    statCalc.reset(new ConsoleStatCalc(op->getAsInt(PREF_SUMMARY_INTERVAL)));
+    statCalc.reset(new ConsoleStatCalc(op->getAsInt(PREF_SUMMARY_INTERVAL),
+                                       op->getAsBool(PREF_HUMAN_READABLE)));
   }
   return statCalc;
 }
@@ -143,18 +143,18 @@ static void showFiles
     try {
 #ifdef ENABLE_BITTORRENT
       if(dt.guessTorrentFile(*i)) {
-	showTorrentFile(*i);
+        showTorrentFile(*i);
       } else
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
-	if(dt.guessMetalinkFile(*i)) {
-	  showMetalinkFile(*i, op);
-	} else
+        if(dt.guessMetalinkFile(*i)) {
+          showMetalinkFile(*i, op);
+        } else
 #endif // ENABLE_METALINK
-	  {
-	    printf(MSG_NOT_TORRENT_METALINK);
-	    printf("\n\n");
-	  }
+          {
+            printf(MSG_NOT_TORRENT_METALINK);
+            printf("\n\n");
+          }
     } catch(RecoverableException& e) {
       std::cout << e.stackTrace() << std::endl;
     }
@@ -163,7 +163,7 @@ static void showFiles
 #endif // ENABLE_BITTORRENT || ENABLE_METALINK
 
 extern void option_processing(Option& option, std::deque<std::string>& uris,
-			      int argc, char* const argv[]);
+                              int argc, char* const argv[]);
 
 downloadresultcode::RESULT main(int argc, char* argv[])
 {
@@ -172,16 +172,15 @@ downloadresultcode::RESULT main(int argc, char* argv[])
   option_processing(*op.get(), args, argc, argv);
 
   SimpleRandomizer::init();
-  BitfieldManFactory::setDefaultRandomizer(SimpleRandomizer::getInstance());
 #ifdef ENABLE_BITTORRENT
   bittorrent::generateStaticPeerId(op->get(PREF_PEER_ID_PREFIX));
 #endif // ENABLE_BITTORRENT
   if(op->get(PREF_LOG) == "-") {
     LogFactory::setLogFile(DEV_STDOUT);
-  } else if(!op->get(PREF_LOG).empty()) {
-    LogFactory::setLogFile(op->get(PREF_LOG));
-  } else {
+  } else if(op->blank(PREF_LOG)) {
     LogFactory::setLogFile(DEV_NULL);
+  } else {
+    LogFactory::setLogFile(op->get(PREF_LOG));
   }
   LogFactory::setLogLevel(op->get(PREF_LOG_LEVEL));
   if(op->getAsBool(PREF_QUIET)) {
@@ -196,102 +195,105 @@ downloadresultcode::RESULT main(int argc, char* argv[])
       SocketCore::useSelect();
     }
   downloadresultcode::RESULT exitStatus = downloadresultcode::FINISHED;
-  try {
-    Logger* logger = LogFactory::getInstance();
-    logger->info("<<--- --- --- ---");
-    logger->info("  --- --- --- ---");
-    logger->info("  --- --- --- --->>");
-    logger->info("%s %s %s", PACKAGE, PACKAGE_VERSION, TARGET);
-    logger->info(MSG_LOGGING_STARTED);
+
+  Logger* logger = LogFactory::getInstance();
+  logger->info("<<--- --- --- ---");
+  logger->info("  --- --- --- ---");
+  logger->info("  --- --- --- --->>");
+  logger->info("%s %s %s", PACKAGE, PACKAGE_VERSION, TARGET);
+  logger->info(MSG_LOGGING_STARTED);
 
 #ifdef ENABLE_MESSAGE_DIGEST
-    MessageDigestHelper::staticSHA1DigestInit();
+  MessageDigestHelper::staticSHA1DigestInit();
 #endif // ENABLE_MESSAGE_DIGEST
 
-    if(op->getAsBool(PREF_DISABLE_IPV6)) {
-      SocketCore::setProtocolFamily(AF_INET);
-    }
-    // Bind interface
-    if(!op->get(PREF_INTERFACE).empty()) {
-      std::string interface = op->get(PREF_INTERFACE);
-      SocketCore::bindAddress(interface);
-    }
+  if(op->getAsBool(PREF_DISABLE_IPV6)) {
+    SocketCore::setProtocolFamily(AF_INET);
+    // Get rid of AI_ADDRCONFIG. It causes name resolution error
+    // when none of network interface has IPv4 address.
+    setDefaultAIFlags(0);
+  }
+  // Bind interface
+  if(!op->get(PREF_INTERFACE).empty()) {
+    std::string iface = op->get(PREF_INTERFACE);
+    SocketCore::bindAddress(iface);
+  }
 
 #ifdef SIGPIPE
-    util::setGlobalSignalHandler(SIGPIPE, SIG_IGN, 0);
+  util::setGlobalSignalHandler(SIGPIPE, SIG_IGN, 0);
 #endif
 #ifdef SIGCHLD
-    // Avoid to create zombie process when forked child processes are
-    // died.
-    util::setGlobalSignalHandler(SIGCHLD, SIG_IGN, 0);
+  // Avoid to create zombie process when forked child processes are
+  // died.
+  util::setGlobalSignalHandler(SIGCHLD, SIG_IGN, 0);
 #endif // SIGCHILD
-    std::deque<SharedHandle<RequestGroup> > requestGroups;
+  std::deque<SharedHandle<RequestGroup> > requestGroups;
 #ifdef ENABLE_BITTORRENT
-    if(!op->blank(PREF_TORRENT_FILE)) {
+  if(!op->blank(PREF_TORRENT_FILE)) {
+    if(op->get(PREF_SHOW_FILES) == V_TRUE) {
+      showTorrentFile(op->get(PREF_TORRENT_FILE));
+      return exitStatus;
+    } else {
+      createRequestGroupForBitTorrent(requestGroups, op, args);
+    }
+  }
+  else
+#endif // ENABLE_BITTORRENT
+#ifdef ENABLE_METALINK
+    if(!op->blank(PREF_METALINK_FILE)) {
       if(op->get(PREF_SHOW_FILES) == V_TRUE) {
-	showTorrentFile(op->get(PREF_TORRENT_FILE));
-	return exitStatus;
+        showMetalinkFile(op->get(PREF_METALINK_FILE), op);
+        return exitStatus;
       } else {
-	createRequestGroupForBitTorrent(requestGroups, op, args);
+        createRequestGroupForMetalink(requestGroups, op);
       }
     }
     else
-#endif // ENABLE_BITTORRENT
-#ifdef ENABLE_METALINK
-      if(!op->blank(PREF_METALINK_FILE)) {
-	if(op->get(PREF_SHOW_FILES) == V_TRUE) {
-	  showMetalinkFile(op->get(PREF_METALINK_FILE), op);
-	  return exitStatus;
-	} else {
-	  createRequestGroupForMetalink(requestGroups, op);
-	}
-      }
-      else
 #endif // ENABLE_METALINK
-	if(!op->blank(PREF_INPUT_FILE)) {
-	  createRequestGroupForUriList(requestGroups, op);
+      if(!op->blank(PREF_INPUT_FILE)) {
+        createRequestGroupForUriList(requestGroups, op);
 #if defined ENABLE_BITTORRENT || defined ENABLE_METALINK
-	} else if(op->get(PREF_SHOW_FILES) == V_TRUE) {
-	  showFiles(args, op);
-	  return exitStatus;
+      } else if(op->get(PREF_SHOW_FILES) == V_TRUE) {
+        showFiles(args, op);
+        return exitStatus;
 #endif // ENABLE_METALINK || ENABLE_METALINK
-	} else {
-	  createRequestGroupForUri(requestGroups, op, args);
-	}
+      } else {
+        createRequestGroupForUri(requestGroups, op, args);
+      }
 
-    // Remove option values which is only valid for URIs specified in
-    // command-line. If they are left, because op is used as a
-    // template for new RequestGroup(such as created in XML-RPC
-    // command), they causes unintentional effect.
-    op->remove(PREF_OUT);
-    op->remove(PREF_FORCE_SEQUENTIAL);
-    op->remove(PREF_INPUT_FILE);
-    op->remove(PREF_INDEX_OUT);
-    op->remove(PREF_SELECT_FILE);
-    if(
+  // Remove option values which is only valid for URIs specified in
+  // command-line. If they are left, because op is used as a
+  // template for new RequestGroup(such as created in XML-RPC
+  // command), they causes unintentional effect.
+  op->remove(PREF_OUT);
+  op->remove(PREF_FORCE_SEQUENTIAL);
+  op->remove(PREF_INPUT_FILE);
+  op->remove(PREF_INDEX_OUT);
+  op->remove(PREF_SELECT_FILE);
+  if(
 #ifdef ENABLE_XML_RPC
-       !op->getAsBool(PREF_ENABLE_XML_RPC) &&
+     !op->getAsBool(PREF_ENABLE_XML_RPC) &&
 #endif // ENABLE_XML_RPC
-       requestGroups.empty()) {
-      std::cout << MSG_NO_FILES_TO_DOWNLOAD << std::endl;
-    } else {
-      exitStatus = MultiUrlRequestInfo(requestGroups, op, getStatCalc(op),
-				       getSummaryOut(op)).execute();
-    }
-  } catch(Exception& ex) {
-    std::cerr << EX_EXCEPTION_CAUGHT << "\n" << ex.stackTrace() << std::endl;
-    exitStatus = downloadresultcode::UNKNOWN_ERROR;
+     requestGroups.empty()) {
+    std::cout << MSG_NO_FILES_TO_DOWNLOAD << std::endl;
+  } else {
+    exitStatus = MultiUrlRequestInfo(requestGroups, op, getStatCalc(op),
+                                     getSummaryOut(op)).execute();
   }
-  LogFactory::release();
   return exitStatus;
 }
 
 } // namespace aria2
 
-int main(int argc, char* argv[]) {
-  aria2::Platform platform;
-
-  aria2::downloadresultcode::RESULT r = aria2::main(argc, argv);
-
+int main(int argc, char* argv[])
+{
+  aria2::downloadresultcode::RESULT r;
+  try {
+    aria2::Platform platform;
+    r = aria2::main(argc, argv);
+  } catch(aria2::Exception& ex) {
+    std::cerr << EX_EXCEPTION_CAUGHT << "\n" << ex.stackTrace() << std::endl;
+    r = aria2::downloadresultcode::UNKNOWN_ERROR;
+  }
   return r;
 }
